
From: Adrian Bunk <bunk@fs.tum.de>

Fix compile errors with X86_POWERNOW_K{7,8}=y and ACPI_PROCESSOR=m.

Signed-off-by: Adrian Bunk <bunk@fs.tum.de>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/i386/kernel/cpu/cpufreq/Kconfig       |   10 ++++++++++
 25-akpm/arch/i386/kernel/cpu/cpufreq/powernow-k7.c |   10 +++++-----
 25-akpm/arch/i386/kernel/cpu/cpufreq/powernow-k8.c |    4 ++--
 25-akpm/arch/i386/kernel/cpu/cpufreq/powernow-k8.h |    2 +-
 4 files changed, 18 insertions(+), 8 deletions(-)

diff -puN arch/i386/kernel/cpu/cpufreq/Kconfig~fix-compile-errors-with-x86_powernow_k78=y-and-acpi_processor=m arch/i386/kernel/cpu/cpufreq/Kconfig
--- 25/arch/i386/kernel/cpu/cpufreq/Kconfig~fix-compile-errors-with-x86_powernow_k78=y-and-acpi_processor=m	2004-07-04 23:12:06.270424744 -0700
+++ 25-akpm/arch/i386/kernel/cpu/cpufreq/Kconfig	2004-07-04 23:12:06.278423528 -0700
@@ -88,6 +88,11 @@ config X86_POWERNOW_K7
 
 	  If in doubt, say N.
 
+config X86_POWERNOW_K7_ACPI
+	bool
+	default y
+	depends on (X86_POWERNOW_K7=m && ACPI_PROCESSOR) || (X86_POWERNOW_K7=y && ACPI_PROCESSOR=y)
+
 config X86_POWERNOW_K8
 	tristate "AMD Opteron/Athlon64 PowerNow!"
 	depends on CPU_FREQ && EXPERIMENTAL
@@ -98,6 +103,11 @@ config X86_POWERNOW_K8
 
 	  If in doubt, say N.
 
+config X86_POWERNOW_K8_ACPI
+	bool
+	default y
+	depends on (X86_POWERNOW_K8=m && ACPI_PROCESSOR) || (X86_POWERNOW_K8=y && ACPI_PROCESSOR=y)
+
 config X86_GX_SUSPMOD
 	tristate "Cyrix MediaGX/NatSemi Geode Suspend Modulation"
 	depends on CPU_FREQ
diff -puN arch/i386/kernel/cpu/cpufreq/powernow-k7.c~fix-compile-errors-with-x86_powernow_k78=y-and-acpi_processor=m arch/i386/kernel/cpu/cpufreq/powernow-k7.c
--- 25/arch/i386/kernel/cpu/cpufreq/powernow-k7.c~fix-compile-errors-with-x86_powernow_k78=y-and-acpi_processor=m	2004-07-04 23:12:06.271424592 -0700
+++ 25-akpm/arch/i386/kernel/cpu/cpufreq/powernow-k7.c	2004-07-04 23:12:06.279423376 -0700
@@ -27,7 +27,7 @@
 #include <asm/io.h>
 #include <asm/system.h>
 
-#if defined(CONFIG_ACPI_PROCESSOR) || defined(CONFIG_ACPI_PROCESSOR_MODULE)
+#ifdef CONFIG_X86_POWERNOW_K7_ACPI
 #include <linux/acpi.h>
 #include <acpi/processor.h>
 #endif
@@ -54,7 +54,7 @@ struct pst_s {
 	u8 numpstates;
 };
 
-#if defined(CONFIG_ACPI_PROCESSOR) || defined(CONFIG_ACPI_PROCESSOR_MODULE)
+#ifdef CONFIG_X86_POWERNOW_K7_ACPI
 union powernow_acpi_control_t {
 	struct {
 		unsigned long fid:5,
@@ -196,7 +196,7 @@ static int get_ranges (unsigned char *ps
 		speed = powernow_table[j].frequency;
 
 		if ((fid_codes[fid] % 10)==5) {
-#if defined(CONFIG_ACPI_PROCESSOR) || defined(CONFIG_ACPI_PROCESSOR_MODULE)
+#ifdef CONFIG_X86_POWERNOW_K7_ACPI
 			if (have_a0 == 1)
 				powernow_table[j].frequency = CPUFREQ_ENTRY_INVALID;
 #endif
@@ -300,7 +300,7 @@ static void change_speed (unsigned int i
 }
 
 
-#if defined(CONFIG_ACPI_PROCESSOR) || defined(CONFIG_ACPI_PROCESSOR_MODULE)
+#ifdef CONFIG_X86_POWERNOW_K7_ACPI
 
 struct acpi_processor_performance *acpi_processor_perf;
 
@@ -674,7 +674,7 @@ static int __init powernow_init (void)
 
 static void __exit powernow_exit (void)
 {
-#if defined(CONFIG_ACPI_PROCESSOR) || defined(CONFIG_ACPI_PROCESSOR_MODULE)
+#ifdef CONFIG_X86_POWERNOW_K7_ACPI
 	if (acpi_processor_perf) {
 		acpi_processor_unregister_performance(acpi_processor_perf, 0);
 		kfree(acpi_processor_perf);
diff -puN arch/i386/kernel/cpu/cpufreq/powernow-k8.c~fix-compile-errors-with-x86_powernow_k78=y-and-acpi_processor=m arch/i386/kernel/cpu/cpufreq/powernow-k8.c
--- 25/arch/i386/kernel/cpu/cpufreq/powernow-k8.c~fix-compile-errors-with-x86_powernow_k78=y-and-acpi_processor=m	2004-07-04 23:12:06.273424288 -0700
+++ 25-akpm/arch/i386/kernel/cpu/cpufreq/powernow-k8.c	2004-07-04 23:12:06.280423224 -0700
@@ -32,7 +32,7 @@
 #include <asm/io.h>
 #include <asm/delay.h>
 
-#if defined(CONFIG_ACPI_PROCESSOR) || defined(CONFIG_ACPI_PROCESSOR_MODULE)
+#ifdef CONFIG_X86_POWERNOW_K8_ACPI
 #include <linux/acpi.h>
 #include <acpi/processor.h>
 #endif
@@ -664,7 +664,7 @@ static int find_psb_table(struct powerno
 	return -ENODEV;
 }
 
-#if defined(CONFIG_ACPI_PROCESSOR) || defined(CONFIG_ACPI_PROCESSOR_MODULE)
+#ifdef CONFIG_X86_POWERNOW_K8_ACPI
 static void powernow_k8_acpi_pst_values(struct powernow_k8_data *data, unsigned int index)
 {
 	if (!data->acpi_data.state_count)
diff -puN arch/i386/kernel/cpu/cpufreq/powernow-k8.h~fix-compile-errors-with-x86_powernow_k78=y-and-acpi_processor=m arch/i386/kernel/cpu/cpufreq/powernow-k8.h
--- 25/arch/i386/kernel/cpu/cpufreq/powernow-k8.h~fix-compile-errors-with-x86_powernow_k78=y-and-acpi_processor=m	2004-07-04 23:12:06.274424136 -0700
+++ 25-akpm/arch/i386/kernel/cpu/cpufreq/powernow-k8.h	2004-07-04 23:12:06.281423072 -0700
@@ -29,7 +29,7 @@ struct powernow_k8_data {
 	 * frequency is in kHz */
 	struct cpufreq_frequency_table  *powernow_table;
 
-#if defined(CONFIG_ACPI_PROCESSOR) || defined(CONFIG_ACPI_PROCESSOR_MODULE)
+#ifdef CONFIG_X86_POWERNOW_K8_ACPI
 	/* the acpi table needs to be kept. it's only available if ACPI was
 	 * used to determine valid frequency/vid/fid states */
 	struct acpi_processor_performance acpi_data;
_
